@@ -186,9 +186,7 @@ class EventsRuleToLambdaProps:
         if isinstance(event_rule_props, dict):
             event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(
-                **lambda_function_props
-            )
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         self._values = {
             "event_rule_props": event_rule_props,
         }
